==> react-windows-ui-2.0.4.tgz: package/README.md <==
<h2 align="center"> 
  <img src="https://github.com/virtualvivek/react-windows-ui/blob/main/markdown/md_img_header.png" width="402" /> 
</h2>
<h1 align="center">react-windows-ui</h1>

<p align="center">Build full featured <b>Windows fluent UI</b> apps using <b>ReactJS</b>.</p>

<p align="center">
	
  <a href="https://virtualvivek.github.io/react-windows-ui/">
    <img src="https://img.shields.io/circleci/build/github/virtualvivek/react-windows-ui?style=flat-square&logo=circleci&token=346e79ab71a8d9c3bad22bacbebc7d7c50dae520"
      alt="Build" />
  </a>
	
  <a href="https://github.com/virtualvivek/react-windows-ui/blob/main/LICENSE">
    <img src="https://img.shields.io/badge/License-MIT-darklime.svg?style=flat-square&color=blue"
      alt="License: MIT" />
  </a>
  
  <a href="https://virtualvivek.github.io/react-windows-ui/">
    <img src="https://img.shields.io/github/package-json/v/virtualvivek/react-windows-ui?color=%2331b57e&style=flat-square"
      alt="Version" />
  </a>
  
  <a href="https://virtualvivek.github.io/react-windows-ui/">
    <img src="https://img.shields.io/badge/⚡ Live Demo-here-green.svg?color=%236a31b5&style=flat-square"
      alt="Live Demo" />
  </a>
   
</p>

<h2 align="center">
  <img src="https://github.com/virtualvivek/react-windows-ui/blob/main/markdown/md_img_promo.png" width="652" /> 
</h2>

<h1 align="center">Adaptive UI</h1>
<h2 align="center">
  <img src="https://github.com/virtualvivek/react-windows-ui/blob/main/markdown/md_img_adaptive.gif" width="652" />
</h2>

# Demo ⚡
https://virtualvivek.github.io/react-windows-ui/

# Installation
```js
npm install react-windows-ui
```

# Getting Started

```js
import { NavBar,NavPageContainer, ..} from 'react-windows-ui'
```

```js
// Be sure to include styles at some point, probably during your bootstraping
import 'react-windows-ui/config/app-config.css'
import 'react-windows-ui/dist/react-windows-ui.min.css'
import 'react-windows-ui/icons/fonts/fonts.min.css'
```

### app-config

‣ `app-config.css` file contains the `PrimaryColor`, `Fontfamily` used by the app <br>
‣ You can import default `app-config` using this file <a href="config/app-config.css">app-config.css</a><br>
OR <br>
Create your own like this

```css
:root {
    --PrimaryColor: #6632a8;
    /* Change color you like */
}
body {
    font-family: -apple-system, BlinkMacSystemFont, "Segoe UI", "Helvetica Neue", sans-serif;
    /* Change fontfamily you like */
}
```

# ‣ Example Code
◓ Components full implementation here:<br/>
https://github.com/virtualvivek/react-windows-ui/tree/main/src/demo/framework

# ‣ Library Source Code
◓ Actual npm package used by the project:<br/>
https://github.com/virtualvivek/react-windows-ui/tree/main/src/lib

## ❅ Library Styles SCSS Code
◓ npm package scss source code:<br/>
https://github.com/virtualvivek/react-windows-ui/tree/main/src/source/stylesheet

## Github
https://github.com/virtualvivek/react-windows-ui

## Find this library useful? :heart:
Support it by joining [stargazers](https://github.com/virtualvivek/react-windows-ui/stargazers) for this repository. :star:


## License

`react-windows-ui` is licensed under `MIT license`. View [license](https://github.com/virtualvivek/react-windows-ui/blob/main/LICENSE).<br>
Copyright (c) 2021 ` Vivek Verma `

==> react-windows-ui-2.0.5.tgz: package/README.md <==
<h2 align="center"> 
  <img src="https://github.com/virtualvivek/react-windows-ui/blob/main/markdown/md_img_header.png" width="402" /> 
</h2>
<h1 align="center">react-windows-ui</h1>

<p align="center">Build full featured <b>Windows fluent UI</b> apps using <b>ReactJS</b>.</p>

<p align="center">
	
  <a href="https://virtualvivek.github.io/react-windows-ui/">
    <img src="https://img.shields.io/circleci/build/github/virtualvivek/react-windows-ui?style=flat-square&logo=circleci&token=346e79ab71a8d9c3bad22bacbebc7d7c50dae520"
      alt="Build" />
  </a>
	
  <a href="https://github.com/virtualvivek/react-windows-ui/blob/main/LICENSE">
    <img src="https://img.shields.io/badge/License-MIT-darklime.svg?style=flat-square&color=blue"
      alt="License: MIT" />
  </a>
  
  <a href="https://virtualvivek.github.io/react-windows-ui/">
    <img src="https://img.shields.io/github/package-json/v/virtualvivek/react-windows-ui?color=%2331b57e&style=flat-square"
      alt="Version" />
  </a>
  
  <a href="https://virtualvivek.github.io/react-windows-ui/">
    <img src="https://img.shields.io/badge/⚡ Live Demo-here-green.svg?color=%236a31b5&style=flat-square"
      alt="Live Demo" />
  </a>
   
</p>

<h2 align="center">
  <img src="https://github.com/virtualvivek/react-windows-ui/blob/main/markdown/md_img_promo.png" width="652" /> 
</h2>

<h1 align="center">Adaptive UI</h1>
<h2 align="center">
  <img src="https://github.com/virtualvivek/react-windows-ui/blob/main/markdown/md_img_adaptive.gif" width="652" />
</h2>

# Demo ⚡
https://virtualvivek.github.io/react-windows-ui/

# Installation
```js
npm install react-windows-ui
```

# Getting Started

```js
import { NavBar,NavPageContainer, ..} from 'react-windows-ui'
```

```js
// Be sure to include styles at some point, probably during your bootstraping
import 'react-windows-ui/config/app-config.css'
import 'react-windows-ui/dist/react-windows-ui.min.css'
import 'react-windows-ui/icons/fonts/fonts.min.css'
```

### app-config

‣ `app-config.css` file contains the `PrimaryColor`, `Fontfamily` used by the app <br>
‣ You can import default `app-config` using this file <a href="https://github.com/virtualvivek/react-windows-ui/blob/main/src/lib/config/app-config.css">app-config.css</a><br>
OR <br>
Create your own like this

```css
:root {
    --PrimaryColor: #6632a8;
    /* Change color you like */
}
body {
    font-family: -apple-system, BlinkMacSystemFont, "Segoe UI", "Helvetica Neue", sans-serif;
    /* Change fontfamily you like */
}
```

# ‣ Example Code
◓ Components full implementation here:<br/>
https://github.com/virtualvivek/react-windows-ui/tree/main/src/demo/framework

# ‣ Library Source Code
◓ Actual npm package used by the project:<br/>
https://github.com/virtualvivek/react-windows-ui/tree/main/src/lib

## ❅ Library Styles SCSS Code
◓ npm package scss source code:<br/>
https://github.com/virtualvivek/react-windows-ui/tree/main/src/source/stylesheet

## Github
https://github.com/virtualvivek/react-windows-ui

## Find this library useful? :heart:
Support it by joining [stargazers](https://github.com/virtualvivek/react-windows-ui/stargazers) for this repository. :star:


## License

`react-windows-ui` is licensed under `MIT license`. View [license](https://github.com/virtualvivek/react-windows-ui/blob/main/LICENSE).<br>
Copyright (c) 2021 ` Vivek Verma `
